function DEF=default(data,W)
% DEF=DEFAULT(DATA,W) provides, in the structured variable DEF,
%    the list of all contact defauts in the mechanism described
%    by DATA (NxN structured array where N stands for the number 
%    of bodies) where the N bodies angular rates are given by W
%    (a vector of length N).
%     DEF is a variable with the following structure:
%         DEF.rate   : the angular rate of the defaut,
%         DEF.N      : number of default sources,
%         DEF.joint  : a vector of two integers :[I J] ==> the 
%                      default is the joint between body I and body J,
%         DEF.type   : 'e' or 'p' : type of the joint (gear or pivot),
%         DEF.doc    : string, example:
%                       * 'gear frequency',
%                       * 'default in body I',
%                       * 'default in the inside ring of bearing # 2',
%                       * 'default in the outside ring of bearing # 1',
%                       * 'default in the ball of bearing # 1'.
DEF=[];
for ii=1:length(data),
    for jj=ii+1:length(data),
        if data(ii,jj).type=='e',
            % Default = gear frequency
            kk=bodyref(data,ii,jj);
            DEFc.rate=abs((W(ii)-W(kk))*data(ii,jj).Z1);
            DEFc.N=1;
            DEFc.joint=[ii jj];
            DEFc.type='e';
            DEFc.doc='gear frequency';
            DEF=[DEF;DEFc];
            % D�fault on a particular tooth of gear ii
            DEFc.rate=abs(W(ii)-W(kk));
            DEFc.N=abs(data(ii,jj).Z1);
            DEFc.joint=[ii jj];
            DEFc.type='e';
            DEFc.doc=['default on a tooth of body # ' num2str(ii)];
            DEF=[DEF;DEFc];            
            % D�fault on a particular tooth of gear jj
            DEFc.rate=abs(W(jj)-W(kk));
            DEFc.N=abs(data(ii,jj).Z2);
            DEFc.joint=[ii jj];
            DEFc.type='e';
            DEFc.doc=['default on a tooth of body # ' num2str(jj)];
            DEF=[DEF;DEFc];            
        elseif data(ii,jj).type=='p',
            for kk=1:data(ii,jj).N,
                eval(['bearing=data(ii,jj).B' num2str(kk) ';']);
                diameter=bearing.db*cos(pi/180*bearing.angle);
                % Default on the inner race of bearing #kk :
                DEFc.rate=abs(W(ii)-W(jj))*bearing.Z*(1+diameter/bearing.Dm)/2;
                DEFc.N=1;
                DEFc.joint=[ii jj];
                DEFc.type='p';
                DEFc.doc=['default on body #' num2str(ii) ' on the inner race of bearing # ' num2str(kk)];
                DEF=[DEF;DEFc];            
                % Default on the outer race of bearing #kk :
                DEFc.rate=abs(W(ii)-W(jj))*bearing.Z*(1-diameter/bearing.Dm)/2;
                DEFc.N=1;
                DEFc.joint=[ii jj];
                DEFc.type='p';
                DEFc.doc=['default on body #' num2str(ii) ' on the outer race of bearing # ' num2str(kk)];
                DEF=[DEF;DEFc];            
                % Default on a ball of bearing #kk :
                DEFc.rate=abs(W(ii)-W(jj))*(bearing.Dm/diameter-diameter/bearing.Dm);
                DEFc.N=bearing.Z;
                DEFc.joint=[ii jj];
                DEFc.type='p';
                DEFc.doc=['default on a ball of bearing # ' num2str(kk)];
                DEF=[DEF;DEFc];
            end
        end
    end
end